/********************************************************************************
** Form generated from reading UI file 'localeconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOCALECONFIG_H
#define UI_LOCALECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_LocaleConfig
{
public:
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_2;
    QGridLayout *gridLayout;
    QFormLayout *formLayout;
    QLabel *label_10;
    QComboBox *comboGlobal;
    QCheckBox *checkDetailed;
    QLabel *labelNumbers;
    QComboBox *comboNumbers;
    QLabel *labelTime;
    QComboBox *comboTime;
    QLabel *labelCurrency;
    QComboBox *comboCurrency;
    QLabel *labelMeasurement;
    QComboBox *comboMeasurement;
    QLabel *labelCollate;
    QComboBox *comboCollate;
    QLabel *label_6;
    QLabel *labelMeasurement_2;
    QLabel *lexNumbers;
    QLabel *exampleNumbers;
    QLabel *lexTime;
    QLabel *exampleTime;
    QLabel *lexCurrency;
    QLabel *exampleCurrency;
    QLabel *lexMeasurement_2;
    QLabel *exampleMeasurement;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_5;

    void setupUi(QWidget *LocaleConfig)
    {
        if (LocaleConfig->objectName().isEmpty())
            LocaleConfig->setObjectName(QStringLiteral("LocaleConfig"));
        LocaleConfig->resize(600, 450);
        verticalLayout = new QVBoxLayout(LocaleConfig);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalSpacer_2 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        formLayout = new QFormLayout();
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setHorizontalSpacing(6);
        formLayout->setVerticalSpacing(6);
        label_10 = new QLabel(LocaleConfig);
        label_10->setObjectName(QStringLiteral("label_10"));
        label_10->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::LabelRole, label_10);

        comboGlobal = new QComboBox(LocaleConfig);
        comboGlobal->setObjectName(QStringLiteral("comboGlobal"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboGlobal->sizePolicy().hasHeightForWidth());
        comboGlobal->setSizePolicy(sizePolicy);
        comboGlobal->setMinimumSize(QSize(300, 0));

        formLayout->setWidget(0, QFormLayout::FieldRole, comboGlobal);

        checkDetailed = new QCheckBox(LocaleConfig);
        checkDetailed->setObjectName(QStringLiteral("checkDetailed"));

        formLayout->setWidget(1, QFormLayout::LabelRole, checkDetailed);

        labelNumbers = new QLabel(LocaleConfig);
        labelNumbers->setObjectName(QStringLiteral("labelNumbers"));
        labelNumbers->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::LabelRole, labelNumbers);

        comboNumbers = new QComboBox(LocaleConfig);
        comboNumbers->setObjectName(QStringLiteral("comboNumbers"));
        sizePolicy.setHeightForWidth(comboNumbers->sizePolicy().hasHeightForWidth());
        comboNumbers->setSizePolicy(sizePolicy);
        comboNumbers->setMinimumSize(QSize(300, 0));

        formLayout->setWidget(2, QFormLayout::FieldRole, comboNumbers);

        labelTime = new QLabel(LocaleConfig);
        labelTime->setObjectName(QStringLiteral("labelTime"));
        labelTime->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::LabelRole, labelTime);

        comboTime = new QComboBox(LocaleConfig);
        comboTime->setObjectName(QStringLiteral("comboTime"));
        sizePolicy.setHeightForWidth(comboTime->sizePolicy().hasHeightForWidth());
        comboTime->setSizePolicy(sizePolicy);
        comboTime->setMinimumSize(QSize(300, 0));

        formLayout->setWidget(3, QFormLayout::FieldRole, comboTime);

        labelCurrency = new QLabel(LocaleConfig);
        labelCurrency->setObjectName(QStringLiteral("labelCurrency"));
        labelCurrency->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::LabelRole, labelCurrency);

        comboCurrency = new QComboBox(LocaleConfig);
        comboCurrency->setObjectName(QStringLiteral("comboCurrency"));
        sizePolicy.setHeightForWidth(comboCurrency->sizePolicy().hasHeightForWidth());
        comboCurrency->setSizePolicy(sizePolicy);
        comboCurrency->setMinimumSize(QSize(300, 0));

        formLayout->setWidget(4, QFormLayout::FieldRole, comboCurrency);

        labelMeasurement = new QLabel(LocaleConfig);
        labelMeasurement->setObjectName(QStringLiteral("labelMeasurement"));
        labelMeasurement->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(5, QFormLayout::LabelRole, labelMeasurement);

        comboMeasurement = new QComboBox(LocaleConfig);
        comboMeasurement->setObjectName(QStringLiteral("comboMeasurement"));
        sizePolicy.setHeightForWidth(comboMeasurement->sizePolicy().hasHeightForWidth());
        comboMeasurement->setSizePolicy(sizePolicy);
        comboMeasurement->setMinimumSize(QSize(300, 0));

        formLayout->setWidget(5, QFormLayout::FieldRole, comboMeasurement);

        labelCollate = new QLabel(LocaleConfig);
        labelCollate->setObjectName(QStringLiteral("labelCollate"));
        labelCollate->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(6, QFormLayout::LabelRole, labelCollate);

        comboCollate = new QComboBox(LocaleConfig);
        comboCollate->setObjectName(QStringLiteral("comboCollate"));
        sizePolicy.setHeightForWidth(comboCollate->sizePolicy().hasHeightForWidth());
        comboCollate->setSizePolicy(sizePolicy);
        comboCollate->setMinimumSize(QSize(300, 0));

        formLayout->setWidget(6, QFormLayout::FieldRole, comboCollate);

        label_6 = new QLabel(LocaleConfig);
        label_6->setObjectName(QStringLiteral("label_6"));
        label_6->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(7, QFormLayout::LabelRole, label_6);

        labelMeasurement_2 = new QLabel(LocaleConfig);
        labelMeasurement_2->setObjectName(QStringLiteral("labelMeasurement_2"));
        labelMeasurement_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(8, QFormLayout::LabelRole, labelMeasurement_2);

        lexNumbers = new QLabel(LocaleConfig);
        lexNumbers->setObjectName(QStringLiteral("lexNumbers"));
        lexNumbers->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(9, QFormLayout::LabelRole, lexNumbers);

        exampleNumbers = new QLabel(LocaleConfig);
        exampleNumbers->setObjectName(QStringLiteral("exampleNumbers"));
        exampleNumbers->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(9, QFormLayout::FieldRole, exampleNumbers);

        lexTime = new QLabel(LocaleConfig);
        lexTime->setObjectName(QStringLiteral("lexTime"));
        lexTime->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(10, QFormLayout::LabelRole, lexTime);

        exampleTime = new QLabel(LocaleConfig);
        exampleTime->setObjectName(QStringLiteral("exampleTime"));
        exampleTime->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(10, QFormLayout::FieldRole, exampleTime);

        lexCurrency = new QLabel(LocaleConfig);
        lexCurrency->setObjectName(QStringLiteral("lexCurrency"));
        lexCurrency->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(11, QFormLayout::LabelRole, lexCurrency);

        exampleCurrency = new QLabel(LocaleConfig);
        exampleCurrency->setObjectName(QStringLiteral("exampleCurrency"));
        exampleCurrency->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(11, QFormLayout::FieldRole, exampleCurrency);

        lexMeasurement_2 = new QLabel(LocaleConfig);
        lexMeasurement_2->setObjectName(QStringLiteral("lexMeasurement_2"));
        lexMeasurement_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(12, QFormLayout::LabelRole, lexMeasurement_2);

        exampleMeasurement = new QLabel(LocaleConfig);
        exampleMeasurement->setObjectName(QStringLiteral("exampleMeasurement"));
        exampleMeasurement->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(12, QFormLayout::FieldRole, exampleMeasurement);


        gridLayout->addLayout(formLayout, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer_3 = new QSpacerItem(20, 32, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);

        label_5 = new QLabel(LocaleConfig);
        label_5->setObjectName(QStringLiteral("label_5"));

        verticalLayout->addWidget(label_5);

#ifndef QT_NO_SHORTCUT
        label_10->setBuddy(comboGlobal);
        labelNumbers->setBuddy(comboNumbers);
        labelTime->setBuddy(comboTime);
        labelCurrency->setBuddy(comboCurrency);
        labelMeasurement->setBuddy(comboMeasurement);
        labelCollate->setBuddy(comboCollate);
#endif // QT_NO_SHORTCUT

        retranslateUi(LocaleConfig);

        QMetaObject::connectSlotsByName(LocaleConfig);
    } // setupUi

    void retranslateUi(QWidget *LocaleConfig)
    {
        label_10->setText(QApplication::translate("LocaleConfig", "Re&gion:", Q_NULLPTR));
        checkDetailed->setText(QApplication::translate("LocaleConfig", "De&tailed Settings", Q_NULLPTR));
        labelNumbers->setText(QApplication::translate("LocaleConfig", "&Numbers:", Q_NULLPTR));
        labelTime->setText(QApplication::translate("LocaleConfig", "&Time:", Q_NULLPTR));
        labelCurrency->setText(QApplication::translate("LocaleConfig", "Currenc&y:", Q_NULLPTR));
        labelMeasurement->setText(QApplication::translate("LocaleConfig", "Measurement &Units:", Q_NULLPTR));
        labelCollate->setText(QApplication::translate("LocaleConfig", "Co&llation and Sorting:", Q_NULLPTR));
        label_6->setText(QString());
        labelMeasurement_2->setText(QApplication::translate("LocaleConfig", "<b>Examples</b>", Q_NULLPTR));
        lexNumbers->setText(QApplication::translate("LocaleConfig", "Numbers:", Q_NULLPTR));
        exampleNumbers->setText(QString());
        lexTime->setText(QApplication::translate("LocaleConfig", "Time:", Q_NULLPTR));
        exampleTime->setText(QString());
        lexCurrency->setText(QApplication::translate("LocaleConfig", "Currency:", Q_NULLPTR));
        exampleCurrency->setText(QString());
        lexMeasurement_2->setText(QApplication::translate("LocaleConfig", "Measurement Units:", Q_NULLPTR));
        exampleMeasurement->setText(QString());
        label_5->setText(QString());
        Q_UNUSED(LocaleConfig);
    } // retranslateUi

};

namespace Ui {
    class LocaleConfig: public Ui_LocaleConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LOCALECONFIG_H
