/********************************************************************************
** Form generated from reading UI file 'selectwnd.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTWND_H
#define UI_SELECTWND_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "previewwidget.h"
#include "warninglabel.h"

QT_BEGIN_NAMESPACE

class Ui_SelectWnd
{
public:
    QGridLayout *gridLayout;
    QLabel *infoLabel;
    WarningLabel *warningLabel;
    PreviewWidget *preview;
    QListView *lbThemes;
    QSpacerItem *spacerItem;
    QPushButton *btInstall;
    QPushButton *btRemove;

    void setupUi(QWidget *SelectWnd)
    {
        if (SelectWnd->objectName().isEmpty())
            SelectWnd->setObjectName(QStringLiteral("SelectWnd"));
        SelectWnd->resize(384, 353);
        gridLayout = new QGridLayout(SelectWnd);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        infoLabel = new QLabel(SelectWnd);
        infoLabel->setObjectName(QStringLiteral("infoLabel"));
        infoLabel->setWordWrap(true);

        gridLayout->addWidget(infoLabel, 0, 0, 1, 4);

        warningLabel = new WarningLabel(SelectWnd);
        warningLabel->setObjectName(QStringLiteral("warningLabel"));

        gridLayout->addWidget(warningLabel, 1, 0, 1, 4);

        preview = new PreviewWidget(SelectWnd);
        preview->setObjectName(QStringLiteral("preview"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(preview->sizePolicy().hasHeightForWidth());
        preview->setSizePolicy(sizePolicy);
        preview->setMinimumSize(QSize(0, 48));

        gridLayout->addWidget(preview, 2, 0, 1, 4);

        lbThemes = new QListView(SelectWnd);
        lbThemes->setObjectName(QStringLiteral("lbThemes"));
        lbThemes->setEditTriggers(QAbstractItemView::NoEditTriggers);
        lbThemes->setProperty("showDropIndicator", QVariant(false));
        lbThemes->setAlternatingRowColors(true);
        lbThemes->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        gridLayout->addWidget(lbThemes, 3, 0, 1, 4);

        spacerItem = new QSpacerItem(174, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 4, 0, 1, 1);

        btInstall = new QPushButton(SelectWnd);
        btInstall->setObjectName(QStringLiteral("btInstall"));
        btInstall->setEnabled(false);

        gridLayout->addWidget(btInstall, 4, 1, 1, 1);

        btRemove = new QPushButton(SelectWnd);
        btRemove->setObjectName(QStringLiteral("btRemove"));

        gridLayout->addWidget(btRemove, 4, 2, 1, 1);

        QWidget::setTabOrder(lbThemes, btInstall);
        QWidget::setTabOrder(btInstall, btRemove);

        retranslateUi(SelectWnd);

        QMetaObject::connectSlotsByName(SelectWnd);
    } // setupUi

    void retranslateUi(QWidget *SelectWnd)
    {
        SelectWnd->setWindowTitle(QApplication::translate("SelectWnd", "LXQt Mouse Theme Configuration", Q_NULLPTR));
        infoLabel->setText(QApplication::translate("SelectWnd", "Select the cursor theme you want to use (hover preview to test cursor). <b>LXQt session needs restart after this change</b>:", Q_NULLPTR));
        btInstall->setText(QApplication::translate("SelectWnd", "&Install New Theme...", Q_NULLPTR));
        btRemove->setText(QApplication::translate("SelectWnd", "&Remove Theme", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class SelectWnd: public Ui_SelectWnd {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SELECTWND_H
