/********************************************************************************
** Form generated from reading UI file 'brightnesssettings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BRIGHTNESSSETTINGS_H
#define UI_BRIGHTNESSSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_BrightnessSettings
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QVBoxLayout *layout;
    QCheckBox *confirmCB;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BrightnessSettings)
    {
        if (BrightnessSettings->objectName().isEmpty())
            BrightnessSettings->setObjectName(QStringLiteral("BrightnessSettings"));
        BrightnessSettings->resize(406, 110);
        QIcon icon;
        QString iconThemeName = QStringLiteral("system");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        BrightnessSettings->setWindowIcon(icon);
        verticalLayout = new QVBoxLayout(BrightnessSettings);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        label = new QLabel(BrightnessSettings);
        label->setObjectName(QStringLiteral("label"));

        verticalLayout->addWidget(label);

        layout = new QVBoxLayout();
        layout->setObjectName(QStringLiteral("layout"));

        verticalLayout->addLayout(layout);

        confirmCB = new QCheckBox(BrightnessSettings);
        confirmCB->setObjectName(QStringLiteral("confirmCB"));
        confirmCB->setChecked(true);

        verticalLayout->addWidget(confirmCB);

        buttonBox = new QDialogButtonBox(BrightnessSettings);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(BrightnessSettings);
        QObject::connect(buttonBox, SIGNAL(accepted()), BrightnessSettings, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), BrightnessSettings, SLOT(reject()));

        QMetaObject::connectSlotsByName(BrightnessSettings);
    } // setupUi

    void retranslateUi(QDialog *BrightnessSettings)
    {
        BrightnessSettings->setWindowTitle(QApplication::translate("BrightnessSettings", "Brightness Settings", Q_NULLPTR));
        label->setText(QApplication::translate("BrightnessSettings", "<html><head/><body><p><span style=\" font-weight:600;\">Backlight and brightness settings:</span></p><p>Use arrow keys to change settings.</p></body></html>", Q_NULLPTR));
        confirmCB->setText(QApplication::translate("BrightnessSettings", "Require confirmation after settings change", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class BrightnessSettings: public Ui_BrightnessSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BRIGHTNESSSETTINGS_H
