/********************************************************************************
** Form generated from reading UI file 'styleconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STYLECONFIG_H
#define UI_STYLECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_StyleConfig
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QTreeWidget *styleList;
    QLabel *label_2;
    QComboBox *toolButtonStyle;
    QCheckBox *singleClickActivate;

    void setupUi(QWidget *StyleConfig)
    {
        if (StyleConfig->objectName().isEmpty())
            StyleConfig->setObjectName(QStringLiteral("StyleConfig"));
        StyleConfig->resize(490, 363);
        formLayout = new QFormLayout(StyleConfig);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        label = new QLabel(StyleConfig);
        label->setObjectName(QStringLiteral("label"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);

        formLayout->setWidget(0, QFormLayout::LabelRole, label);

        styleList = new QTreeWidget(StyleConfig);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        styleList->setHeaderItem(__qtreewidgetitem);
        styleList->setObjectName(QStringLiteral("styleList"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(styleList->sizePolicy().hasHeightForWidth());
        styleList->setSizePolicy(sizePolicy);
        styleList->setAlternatingRowColors(true);
        styleList->setRootIsDecorated(false);
        styleList->header()->setVisible(false);

        formLayout->setWidget(1, QFormLayout::SpanningRole, styleList);

        label_2 = new QLabel(StyleConfig);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout->setWidget(2, QFormLayout::LabelRole, label_2);

        toolButtonStyle = new QComboBox(StyleConfig);
        toolButtonStyle->setObjectName(QStringLiteral("toolButtonStyle"));

        formLayout->setWidget(2, QFormLayout::FieldRole, toolButtonStyle);

        singleClickActivate = new QCheckBox(StyleConfig);
        singleClickActivate->setObjectName(QStringLiteral("singleClickActivate"));

        formLayout->setWidget(3, QFormLayout::SpanningRole, singleClickActivate);


        retranslateUi(StyleConfig);

        QMetaObject::connectSlotsByName(StyleConfig);
    } // setupUi

    void retranslateUi(QWidget *StyleConfig)
    {
        label->setText(QApplication::translate("StyleConfig", "Widget Style", Q_NULLPTR));
        label_2->setText(QApplication::translate("StyleConfig", "Toolbar button style:", Q_NULLPTR));
        toolButtonStyle->clear();
        toolButtonStyle->insertItems(0, QStringList()
         << QApplication::translate("StyleConfig", "Only display the icon", Q_NULLPTR)
         << QApplication::translate("StyleConfig", "Only display the text", Q_NULLPTR)
         << QApplication::translate("StyleConfig", "The text appears beside the icon", Q_NULLPTR)
         << QApplication::translate("StyleConfig", "The text appears under the icon", Q_NULLPTR)
         << QApplication::translate("StyleConfig", "Default", Q_NULLPTR)
        );
        singleClickActivate->setText(QApplication::translate("StyleConfig", "Activate item on single click", Q_NULLPTR));
        Q_UNUSED(StyleConfig);
    } // retranslateUi

};

namespace Ui {
    class StyleConfig: public Ui_StyleConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_STYLECONFIG_H
