/********************************************************************************
** Form generated from reading UI file 'mouseconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUSECONFIG_H
#define UI_MOUSECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MouseConfig
{
public:
    QFormLayout *formLayout;
    QLabel *label_43;
    QGroupBox *groupBox_5;
    QGridLayout *gridLayout_5;
    QLabel *label_35;
    QLabel *label_36;
    QLabel *label_37;
    QLabel *label_38;
    QSlider *mouseThreshold;
    QLabel *label_39;
    QSlider *mouseAccel;
    QLabel *label_40;
    QLabel *label_41;
    QLabel *label_42;
    QLabel *label;
    QSpinBox *doubleClickInterval;
    QLabel *label_2;
    QSpinBox *wheelScrollLines;
    QCheckBox *mouseLeftHanded;
    QCheckBox *singleClick;

    void setupUi(QWidget *MouseConfig)
    {
        if (MouseConfig->objectName().isEmpty())
            MouseConfig->setObjectName(QStringLiteral("MouseConfig"));
        MouseConfig->resize(324, 223);
        formLayout = new QFormLayout(MouseConfig);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_43 = new QLabel(MouseConfig);
        label_43->setObjectName(QStringLiteral("label_43"));

        formLayout->setWidget(0, QFormLayout::SpanningRole, label_43);

        groupBox_5 = new QGroupBox(MouseConfig);
        groupBox_5->setObjectName(QStringLiteral("groupBox_5"));
        gridLayout_5 = new QGridLayout(groupBox_5);
        gridLayout_5->setObjectName(QStringLiteral("gridLayout_5"));
        label_35 = new QLabel(groupBox_5);
        label_35->setObjectName(QStringLiteral("label_35"));

        gridLayout_5->addWidget(label_35, 1, 3, 1, 1);

        label_36 = new QLabel(groupBox_5);
        label_36->setObjectName(QStringLiteral("label_36"));

        gridLayout_5->addWidget(label_36, 0, 3, 1, 1);

        label_37 = new QLabel(groupBox_5);
        label_37->setObjectName(QStringLiteral("label_37"));

        gridLayout_5->addWidget(label_37, 1, 0, 1, 1);

        label_38 = new QLabel(groupBox_5);
        label_38->setObjectName(QStringLiteral("label_38"));

        gridLayout_5->addWidget(label_38, 1, 1, 1, 1);

        mouseThreshold = new QSlider(groupBox_5);
        mouseThreshold->setObjectName(QStringLiteral("mouseThreshold"));
        mouseThreshold->setMinimum(10);
        mouseThreshold->setMaximum(110);
        mouseThreshold->setSingleStep(10);
        mouseThreshold->setOrientation(Qt::Horizontal);
        mouseThreshold->setTickPosition(QSlider::TicksAbove);

        gridLayout_5->addWidget(mouseThreshold, 1, 2, 1, 1);

        label_39 = new QLabel(groupBox_5);
        label_39->setObjectName(QStringLiteral("label_39"));

        gridLayout_5->addWidget(label_39, 0, 0, 1, 1);

        mouseAccel = new QSlider(groupBox_5);
        mouseAccel->setObjectName(QStringLiteral("mouseAccel"));
        mouseAccel->setMinimum(10);
        mouseAccel->setMaximum(110);
        mouseAccel->setSingleStep(10);
        mouseAccel->setOrientation(Qt::Horizontal);
        mouseAccel->setTickPosition(QSlider::TicksAbove);

        gridLayout_5->addWidget(mouseAccel, 0, 2, 1, 1);

        label_40 = new QLabel(groupBox_5);
        label_40->setObjectName(QStringLiteral("label_40"));

        gridLayout_5->addWidget(label_40, 0, 1, 1, 1);

        label_41 = new QLabel(groupBox_5);
        label_41->setObjectName(QStringLiteral("label_41"));

        gridLayout_5->addWidget(label_41, 0, 4, 1, 1);

        label_42 = new QLabel(groupBox_5);
        label_42->setObjectName(QStringLiteral("label_42"));

        gridLayout_5->addWidget(label_42, 1, 4, 1, 1);


        formLayout->setWidget(1, QFormLayout::SpanningRole, groupBox_5);

        label = new QLabel(MouseConfig);
        label->setObjectName(QStringLiteral("label"));

        formLayout->setWidget(4, QFormLayout::LabelRole, label);

        doubleClickInterval = new QSpinBox(MouseConfig);
        doubleClickInterval->setObjectName(QStringLiteral("doubleClickInterval"));
        doubleClickInterval->setMaximum(10000);

        formLayout->setWidget(4, QFormLayout::FieldRole, doubleClickInterval);

        label_2 = new QLabel(MouseConfig);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout->setWidget(5, QFormLayout::LabelRole, label_2);

        wheelScrollLines = new QSpinBox(MouseConfig);
        wheelScrollLines->setObjectName(QStringLiteral("wheelScrollLines"));

        formLayout->setWidget(5, QFormLayout::FieldRole, wheelScrollLines);

        mouseLeftHanded = new QCheckBox(MouseConfig);
        mouseLeftHanded->setObjectName(QStringLiteral("mouseLeftHanded"));

        formLayout->setWidget(7, QFormLayout::SpanningRole, mouseLeftHanded);

        singleClick = new QCheckBox(MouseConfig);
        singleClick->setObjectName(QStringLiteral("singleClick"));

        formLayout->setWidget(6, QFormLayout::SpanningRole, singleClick);


        retranslateUi(MouseConfig);
        QObject::connect(mouseAccel, SIGNAL(valueChanged(int)), label_41, SLOT(setNum(int)));
        QObject::connect(mouseThreshold, SIGNAL(valueChanged(int)), label_42, SLOT(setNum(int)));

        QMetaObject::connectSlotsByName(MouseConfig);
    } // setupUi

    void retranslateUi(QWidget *MouseConfig)
    {
        MouseConfig->setWindowTitle(QApplication::translate("MouseConfig", "Form", Q_NULLPTR));
        label_43->setText(QApplication::translate("MouseConfig", "<b>Mouse</b>", Q_NULLPTR));
        groupBox_5->setTitle(QApplication::translate("MouseConfig", "Motion", Q_NULLPTR));
        label_35->setText(QApplication::translate("MouseConfig", "High", Q_NULLPTR));
        label_36->setText(QApplication::translate("MouseConfig", "Fast", Q_NULLPTR));
        label_37->setText(QApplication::translate("MouseConfig", "Sensitivity:", Q_NULLPTR));
        label_38->setText(QApplication::translate("MouseConfig", "Low", Q_NULLPTR));
        label_39->setText(QApplication::translate("MouseConfig", "Acceleration:", Q_NULLPTR));
        label_40->setText(QApplication::translate("MouseConfig", "Slow", Q_NULLPTR));
        label_41->setText(QApplication::translate("MouseConfig", "0", Q_NULLPTR));
        label_42->setText(QApplication::translate("MouseConfig", "0", Q_NULLPTR));
        label->setText(QApplication::translate("MouseConfig", "Double click interval:", Q_NULLPTR));
        doubleClickInterval->setSuffix(QApplication::translate("MouseConfig", " ms", Q_NULLPTR));
        label_2->setText(QApplication::translate("MouseConfig", "Wheel scroll lines:", Q_NULLPTR));
        mouseLeftHanded->setText(QApplication::translate("MouseConfig", "Left handed (Swap left and right mouse buttons)", Q_NULLPTR));
        singleClick->setText(QApplication::translate("MouseConfig", "Single click to activate items", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class MouseConfig: public Ui_MouseConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MOUSECONFIG_H
