/********************************************************************************
** Form generated from reading UI file 'outputwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OUTPUTWIDGET_H
#define UI_OUTPUTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDial>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OutputWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSlider *backlightSlider;
    QDial *brightnessSlider;

    void setupUi(QWidget *OutputWidget)
    {
        if (OutputWidget->objectName().isEmpty())
            OutputWidget->setObjectName(QStringLiteral("OutputWidget"));
        OutputWidget->resize(478, 86);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OutputWidget->sizePolicy().hasHeightForWidth());
        OutputWidget->setSizePolicy(sizePolicy);
        OutputWidget->setWindowTitle(QStringLiteral("Form"));
        verticalLayout = new QVBoxLayout(OutputWidget);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        frame = new QFrame(OutputWidget);
        frame->setObjectName(QStringLiteral("frame"));
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        frame->setLineWidth(5);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(frame);
        label->setObjectName(QStringLiteral("label"));
        label->setTextFormat(Qt::RichText);

        horizontalLayout->addWidget(label);

        backlightSlider = new QSlider(frame);
        backlightSlider->setObjectName(QStringLiteral("backlightSlider"));
        backlightSlider->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(backlightSlider);

        brightnessSlider = new QDial(frame);
        brightnessSlider->setObjectName(QStringLiteral("brightnessSlider"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(brightnessSlider->sizePolicy().hasHeightForWidth());
        brightnessSlider->setSizePolicy(sizePolicy1);
        brightnessSlider->setMaximumSize(QSize(48, 48));
        brightnessSlider->setWrapping(false);
        brightnessSlider->setNotchTarget(10);
        brightnessSlider->setNotchesVisible(true);

        horizontalLayout->addWidget(brightnessSlider);


        verticalLayout->addWidget(frame);


        retranslateUi(OutputWidget);

        QMetaObject::connectSlotsByName(OutputWidget);
    } // setupUi

    void retranslateUi(QWidget *OutputWidget)
    {
        label->setText(QApplication::translate("OutputWidget", "<b>Output:</b>", Q_NULLPTR));
        Q_UNUSED(OutputWidget);
    } // retranslateUi

};

namespace Ui {
    class OutputWidget: public Ui_OutputWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OUTPUTWIDGET_H
