/********************************************************************************
** Form generated from reading UI file 'fontsconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTSCONFIG_H
#define UI_FONTSCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_FontsConfig
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGroupBox *groupBox;
    QFormLayout *formLayout_3;
    QLabel *label_2;
    QFontComboBox *fontName;
    QLabel *label_6;
    QLabel *label_7;
    QSpinBox *fontSize;
    QComboBox *fontStyle;
    QGroupBox *xftSettings;
    QFormLayout *formLayout_2;
    QCheckBox *antialias;
    QLabel *label_3;
    QComboBox *hintStyle;
    QCheckBox *hinting;
    QLabel *label_5;
    QCheckBox *autohint;
    QSpinBox *dpi;
    QLabel *label_4;
    QComboBox *subpixel;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *FontsConfig)
    {
        if (FontsConfig->objectName().isEmpty())
            FontsConfig->setObjectName(QStringLiteral("FontsConfig"));
        FontsConfig->resize(421, 379);
        verticalLayout = new QVBoxLayout(FontsConfig);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        label = new QLabel(FontsConfig);
        label->setObjectName(QStringLiteral("label"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);

        verticalLayout->addWidget(label);

        groupBox = new QGroupBox(FontsConfig);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        formLayout_3 = new QFormLayout(groupBox);
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout_3->setWidget(0, QFormLayout::LabelRole, label_2);

        fontName = new QFontComboBox(groupBox);
        fontName->setObjectName(QStringLiteral("fontName"));

        formLayout_3->setWidget(0, QFormLayout::FieldRole, fontName);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName(QStringLiteral("label_6"));

        formLayout_3->setWidget(1, QFormLayout::LabelRole, label_6);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName(QStringLiteral("label_7"));

        formLayout_3->setWidget(2, QFormLayout::LabelRole, label_7);

        fontSize = new QSpinBox(groupBox);
        fontSize->setObjectName(QStringLiteral("fontSize"));
        fontSize->setMinimum(4);

        formLayout_3->setWidget(2, QFormLayout::FieldRole, fontSize);

        fontStyle = new QComboBox(groupBox);
        fontStyle->setObjectName(QStringLiteral("fontStyle"));

        formLayout_3->setWidget(1, QFormLayout::FieldRole, fontStyle);


        verticalLayout->addWidget(groupBox);

        xftSettings = new QGroupBox(FontsConfig);
        xftSettings->setObjectName(QStringLiteral("xftSettings"));
        formLayout_2 = new QFormLayout(xftSettings);
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        antialias = new QCheckBox(xftSettings);
        antialias->setObjectName(QStringLiteral("antialias"));

        formLayout_2->setWidget(0, QFormLayout::SpanningRole, antialias);

        label_3 = new QLabel(xftSettings);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout_2->setWidget(3, QFormLayout::LabelRole, label_3);

        hintStyle = new QComboBox(xftSettings);
        hintStyle->setObjectName(QStringLiteral("hintStyle"));
        hintStyle->setEnabled(false);

        formLayout_2->setWidget(3, QFormLayout::FieldRole, hintStyle);

        hinting = new QCheckBox(xftSettings);
        hinting->setObjectName(QStringLiteral("hinting"));

        formLayout_2->setWidget(2, QFormLayout::SpanningRole, hinting);

        label_5 = new QLabel(xftSettings);
        label_5->setObjectName(QStringLiteral("label_5"));

        formLayout_2->setWidget(5, QFormLayout::LabelRole, label_5);

        autohint = new QCheckBox(xftSettings);
        autohint->setObjectName(QStringLiteral("autohint"));

        formLayout_2->setWidget(6, QFormLayout::SpanningRole, autohint);

        dpi = new QSpinBox(xftSettings);
        dpi->setObjectName(QStringLiteral("dpi"));
        dpi->setMinimum(-1);
        dpi->setMaximum(1048576);

        formLayout_2->setWidget(5, QFormLayout::FieldRole, dpi);

        label_4 = new QLabel(xftSettings);
        label_4->setObjectName(QStringLiteral("label_4"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, label_4);

        subpixel = new QComboBox(xftSettings);
        subpixel->setObjectName(QStringLiteral("subpixel"));
        subpixel->setEnabled(false);

        formLayout_2->setWidget(1, QFormLayout::FieldRole, subpixel);


        verticalLayout->addWidget(xftSettings);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(FontsConfig);
        QObject::connect(antialias, SIGNAL(toggled(bool)), subpixel, SLOT(setEnabled(bool)));
        QObject::connect(hinting, SIGNAL(toggled(bool)), hintStyle, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(FontsConfig);
    } // setupUi

    void retranslateUi(QWidget *FontsConfig)
    {
        label->setText(QApplication::translate("FontsConfig", "Font", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("FontsConfig", "Default font for user interface", Q_NULLPTR));
        label_2->setText(QApplication::translate("FontsConfig", "Font name:", Q_NULLPTR));
        label_6->setText(QApplication::translate("FontsConfig", "Style:", Q_NULLPTR));
        label_7->setText(QApplication::translate("FontsConfig", "Point size:", Q_NULLPTR));
        fontStyle->clear();
        fontStyle->insertItems(0, QStringList()
         << QApplication::translate("FontsConfig", "Normal", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "Bold", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "Italic", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "Bold Italic", Q_NULLPTR)
        );
        xftSettings->setTitle(QApplication::translate("FontsConfig", "The following settings only affect newly started applications", Q_NULLPTR));
        antialias->setText(QApplication::translate("FontsConfig", "Use antialias fonts", Q_NULLPTR));
        label_3->setText(QApplication::translate("FontsConfig", "Font hinting style:", Q_NULLPTR));
        hintStyle->clear();
        hintStyle->insertItems(0, QStringList()
         << QApplication::translate("FontsConfig", "None", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "Slight", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "Medium", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "Full", Q_NULLPTR)
        );
        hinting->setText(QApplication::translate("FontsConfig", "Font hinting", Q_NULLPTR));
        label_5->setText(QApplication::translate("FontsConfig", "Resolution (DPI):", Q_NULLPTR));
        autohint->setText(QApplication::translate("FontsConfig", "Autohint", Q_NULLPTR));
        label_4->setText(QApplication::translate("FontsConfig", "Subpixel antialiasing:", Q_NULLPTR));
        subpixel->clear();
        subpixel->insertItems(0, QStringList()
         << QApplication::translate("FontsConfig", "None", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "RGB", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "BGR", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "VRGB", Q_NULLPTR)
         << QApplication::translate("FontsConfig", "VBGR", Q_NULLPTR)
        );
        Q_UNUSED(FontsConfig);
    } // retranslateUi

};

namespace Ui {
    class FontsConfig: public Ui_FontsConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FONTSCONFIG_H
