/****************************************************************************
** Meta object code from reading C++ file 'fontsconfig.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lxqt-config-0.12.0/lxqt-config-appearance/fontsconfig.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fontsconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FontsConfig_t {
    QByteArrayData data[13];
    char stringdata0[151];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FontsConfig_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FontsConfig_t qt_meta_stringdata_FontsConfig = {
    {
QT_MOC_LITERAL(0, 0, 11), // "FontsConfig"
QT_MOC_LITERAL(1, 12, 12), // "initControls"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 12), // "updateQtFont"
QT_MOC_LITERAL(4, 39, 16), // "antialiasToggled"
QT_MOC_LITERAL(5, 56, 7), // "toggled"
QT_MOC_LITERAL(6, 64, 14), // "hintingToggled"
QT_MOC_LITERAL(7, 79, 15), // "subpixelChanged"
QT_MOC_LITERAL(8, 95, 5), // "index"
QT_MOC_LITERAL(9, 101, 16), // "hintStyleChanged"
QT_MOC_LITERAL(10, 118, 10), // "dpiChanged"
QT_MOC_LITERAL(11, 129, 5), // "value"
QT_MOC_LITERAL(12, 135, 15) // "autohintToggled"

    },
    "FontsConfig\0initControls\0\0updateQtFont\0"
    "antialiasToggled\0toggled\0hintingToggled\0"
    "subpixelChanged\0index\0hintStyleChanged\0"
    "dpiChanged\0value\0autohintToggled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FontsConfig[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x0a /* Public */,
       3,    0,   55,    2, 0x08 /* Private */,
       4,    1,   56,    2, 0x08 /* Private */,
       6,    1,   59,    2, 0x08 /* Private */,
       7,    1,   62,    2, 0x08 /* Private */,
       9,    1,   65,    2, 0x08 /* Private */,
      10,    1,   68,    2, 0x08 /* Private */,
      12,    1,   71,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Bool,    5,

       0        // eod
};

void FontsConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FontsConfig *_t = static_cast<FontsConfig *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->initControls(); break;
        case 1: _t->updateQtFont(); break;
        case 2: _t->antialiasToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->hintingToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->subpixelChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->hintStyleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->dpiChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->autohintToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject FontsConfig::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_FontsConfig.data,
      qt_meta_data_FontsConfig,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *FontsConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FontsConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FontsConfig.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int FontsConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
