/********************************************************************************
** Form generated from reading UI file 'iconthemeconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ICONTHEMECONFIG_H
#define UI_ICONTHEMECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_IconThemeConfig
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTreeWidget *iconThemeList;
    QCheckBox *iconFollowColorSchemeCB;

    void setupUi(QWidget *IconThemeConfig)
    {
        if (IconThemeConfig->objectName().isEmpty())
            IconThemeConfig->setObjectName(QStringLiteral("IconThemeConfig"));
        IconThemeConfig->resize(450, 327);
        verticalLayout = new QVBoxLayout(IconThemeConfig);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        label = new QLabel(IconThemeConfig);
        label->setObjectName(QStringLiteral("label"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);

        verticalLayout->addWidget(label);

        iconThemeList = new QTreeWidget(IconThemeConfig);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(3, QStringLiteral("4"));
        __qtreewidgetitem->setText(2, QStringLiteral("3"));
        __qtreewidgetitem->setText(1, QStringLiteral("2"));
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        iconThemeList->setHeaderItem(__qtreewidgetitem);
        iconThemeList->setObjectName(QStringLiteral("iconThemeList"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(iconThemeList->sizePolicy().hasHeightForWidth());
        iconThemeList->setSizePolicy(sizePolicy);
        iconThemeList->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        iconThemeList->setAlternatingRowColors(true);
        iconThemeList->setIconSize(QSize(22, 22));
        iconThemeList->setRootIsDecorated(false);
        iconThemeList->setUniformRowHeights(true);
        iconThemeList->setColumnCount(4);
        iconThemeList->header()->setVisible(false);

        verticalLayout->addWidget(iconThemeList);

        iconFollowColorSchemeCB = new QCheckBox(IconThemeConfig);
        iconFollowColorSchemeCB->setObjectName(QStringLiteral("iconFollowColorSchemeCB"));

        verticalLayout->addWidget(iconFollowColorSchemeCB);


        retranslateUi(IconThemeConfig);

        QMetaObject::connectSlotsByName(IconThemeConfig);
    } // setupUi

    void retranslateUi(QWidget *IconThemeConfig)
    {
        IconThemeConfig->setWindowTitle(QApplication::translate("IconThemeConfig", "LXQt Appearance Configuration", Q_NULLPTR));
        label->setText(QApplication::translate("IconThemeConfig", "Icons Theme", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        iconFollowColorSchemeCB->setToolTip(QApplication::translate("IconThemeConfig", "The KDE extension of XDG icon themes -> FollowsColorScheme", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        iconFollowColorSchemeCB->setText(QApplication::translate("IconThemeConfig", "Colorize icons based on widget style (palette)", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class IconThemeConfig: public Ui_IconThemeConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ICONTHEMECONFIG_H
