/********************************************************************************
** Form generated from reading UI file 'selectkeyboardlayoutdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTKEYBOARDLAYOUTDIALOG_H
#define UI_SELECTKEYBOARDLAYOUTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>

QT_BEGIN_NAMESPACE

class Ui_SelectKeyboardLayoutDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QListWidget *layouts;
    QListWidget *variants;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SelectKeyboardLayoutDialog)
    {
        if (SelectKeyboardLayoutDialog->objectName().isEmpty())
            SelectKeyboardLayoutDialog->setObjectName(QStringLiteral("SelectKeyboardLayoutDialog"));
        SelectKeyboardLayoutDialog->resize(480, 384);
        gridLayout = new QGridLayout(SelectKeyboardLayoutDialog);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label = new QLabel(SelectKeyboardLayoutDialog);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(SelectKeyboardLayoutDialog);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout->addWidget(label_2, 0, 2, 1, 1);

        layouts = new QListWidget(SelectKeyboardLayoutDialog);
        layouts->setObjectName(QStringLiteral("layouts"));
        layouts->setSortingEnabled(true);

        gridLayout->addWidget(layouts, 1, 0, 1, 2);

        variants = new QListWidget(SelectKeyboardLayoutDialog);
        variants->setObjectName(QStringLiteral("variants"));

        gridLayout->addWidget(variants, 1, 2, 1, 1);

        buttonBox = new QDialogButtonBox(SelectKeyboardLayoutDialog);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 3);


        retranslateUi(SelectKeyboardLayoutDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), SelectKeyboardLayoutDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), SelectKeyboardLayoutDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(SelectKeyboardLayoutDialog);
    } // setupUi

    void retranslateUi(QDialog *SelectKeyboardLayoutDialog)
    {
        SelectKeyboardLayoutDialog->setWindowTitle(QApplication::translate("SelectKeyboardLayoutDialog", "Select a keyboard layout", Q_NULLPTR));
        label->setText(QApplication::translate("SelectKeyboardLayoutDialog", "Keyboard layout", Q_NULLPTR));
        label_2->setText(QApplication::translate("SelectKeyboardLayoutDialog", "Variant", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class SelectKeyboardLayoutDialog: public Ui_SelectKeyboardLayoutDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SELECTKEYBOARDLAYOUTDIALOG_H
