/********************************************************************************
** Form generated from reading UI file 'warninglabel.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WARNINGLABEL_H
#define UI_WARNINGLABEL_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_WarningLabel
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *iconLabel;
    QLabel *warningLabel;
    QPushButton *showDirButton;

    void setupUi(QWidget *WarningLabel)
    {
        if (WarningLabel->objectName().isEmpty())
            WarningLabel->setObjectName(QStringLiteral("WarningLabel"));
        WarningLabel->resize(334, 72);
        gridLayout = new QGridLayout(WarningLabel);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        iconLabel = new QLabel(WarningLabel);
        iconLabel->setObjectName(QStringLiteral("iconLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(iconLabel->sizePolicy().hasHeightForWidth());
        iconLabel->setSizePolicy(sizePolicy);
        iconLabel->setMinimumSize(QSize(64, 64));

        horizontalLayout->addWidget(iconLabel);

        warningLabel = new QLabel(WarningLabel);
        warningLabel->setObjectName(QStringLiteral("warningLabel"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(warningLabel->sizePolicy().hasHeightForWidth());
        warningLabel->setSizePolicy(sizePolicy1);
        warningLabel->setWordWrap(true);

        horizontalLayout->addWidget(warningLabel);

        showDirButton = new QPushButton(WarningLabel);
        showDirButton->setObjectName(QStringLiteral("showDirButton"));

        horizontalLayout->addWidget(showDirButton);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);


        retranslateUi(WarningLabel);

        QMetaObject::connectSlotsByName(WarningLabel);
    } // setupUi

    void retranslateUi(QWidget *WarningLabel)
    {
        WarningLabel->setWindowTitle(QApplication::translate("WarningLabel", "Form", Q_NULLPTR));
        warningLabel->setText(QApplication::translate("WarningLabel", "LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:", Q_NULLPTR));
        showDirButton->setText(QApplication::translate("WarningLabel", "Show...", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class WarningLabel: public Ui_WarningLabel {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WARNINGLABEL_H
