/********************************************************************************
** Form generated from reading UI file 'keyboardlayoutconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYBOARDLAYOUTCONFIG_H
#define UI_KEYBOARDLAYOUTCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_KeyboardLayoutConfig
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QTreeWidget *layouts;
    QVBoxLayout *verticalLayout;
    QPushButton *addLayout;
    QPushButton *removeLayout;
    QPushButton *moveUp;
    QPushButton *moveDown;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QComboBox *keyboardModel;
    QLabel *label_3;
    QComboBox *switchKey;
    QLabel *label_4;

    void setupUi(QWidget *KeyboardLayoutConfig)
    {
        if (KeyboardLayoutConfig->objectName().isEmpty())
            KeyboardLayoutConfig->setObjectName(QStringLiteral("KeyboardLayoutConfig"));
        KeyboardLayoutConfig->resize(428, 322);
        formLayout = new QFormLayout(KeyboardLayoutConfig);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label = new QLabel(KeyboardLayoutConfig);
        label->setObjectName(QStringLiteral("label"));

        formLayout->setWidget(0, QFormLayout::SpanningRole, label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        layouts = new QTreeWidget(KeyboardLayoutConfig);
        layouts->setObjectName(QStringLiteral("layouts"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(layouts->sizePolicy().hasHeightForWidth());
        layouts->setSizePolicy(sizePolicy);
        layouts->setDragEnabled(true);
        layouts->setDragDropMode(QAbstractItemView::InternalMove);
        layouts->setRootIsDecorated(false);
        layouts->setItemsExpandable(false);

        horizontalLayout->addWidget(layouts);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        addLayout = new QPushButton(KeyboardLayoutConfig);
        addLayout->setObjectName(QStringLiteral("addLayout"));

        verticalLayout->addWidget(addLayout);

        removeLayout = new QPushButton(KeyboardLayoutConfig);
        removeLayout->setObjectName(QStringLiteral("removeLayout"));

        verticalLayout->addWidget(removeLayout);

        moveUp = new QPushButton(KeyboardLayoutConfig);
        moveUp->setObjectName(QStringLiteral("moveUp"));

        verticalLayout->addWidget(moveUp);

        moveDown = new QPushButton(KeyboardLayoutConfig);
        moveDown->setObjectName(QStringLiteral("moveDown"));

        verticalLayout->addWidget(moveDown);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        verticalLayout->setStretch(4, 1);

        horizontalLayout->addLayout(verticalLayout);

        horizontalLayout->setStretch(0, 1);

        formLayout->setLayout(1, QFormLayout::SpanningRole, horizontalLayout);

        label_2 = new QLabel(KeyboardLayoutConfig);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout->setWidget(2, QFormLayout::LabelRole, label_2);

        keyboardModel = new QComboBox(KeyboardLayoutConfig);
        keyboardModel->setObjectName(QStringLiteral("keyboardModel"));
        keyboardModel->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        formLayout->setWidget(2, QFormLayout::FieldRole, keyboardModel);

        label_3 = new QLabel(KeyboardLayoutConfig);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout->setWidget(3, QFormLayout::LabelRole, label_3);

        switchKey = new QComboBox(KeyboardLayoutConfig);
        switchKey->setObjectName(QStringLiteral("switchKey"));
        switchKey->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        formLayout->setWidget(3, QFormLayout::FieldRole, switchKey);

        label_4 = new QLabel(KeyboardLayoutConfig);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setWordWrap(true);

        formLayout->setWidget(4, QFormLayout::SpanningRole, label_4);


        retranslateUi(KeyboardLayoutConfig);

        QMetaObject::connectSlotsByName(KeyboardLayoutConfig);
    } // setupUi

    void retranslateUi(QWidget *KeyboardLayoutConfig)
    {
        label->setText(QApplication::translate("KeyboardLayoutConfig", "<b>Keyboard Layout</b>", Q_NULLPTR));
        QTreeWidgetItem *___qtreewidgetitem = layouts->headerItem();
        ___qtreewidgetitem->setText(1, QApplication::translate("KeyboardLayoutConfig", "Variant", Q_NULLPTR));
        ___qtreewidgetitem->setText(0, QApplication::translate("KeyboardLayoutConfig", "Layout", Q_NULLPTR));
        addLayout->setText(QApplication::translate("KeyboardLayoutConfig", "&Add", Q_NULLPTR));
        removeLayout->setText(QApplication::translate("KeyboardLayoutConfig", "&Remove", Q_NULLPTR));
        moveUp->setText(QApplication::translate("KeyboardLayoutConfig", "up", Q_NULLPTR));
        moveDown->setText(QApplication::translate("KeyboardLayoutConfig", "down", Q_NULLPTR));
        label_2->setText(QApplication::translate("KeyboardLayoutConfig", "Keyboard model:", Q_NULLPTR));
        label_3->setText(QApplication::translate("KeyboardLayoutConfig", "Keys to change layout:", Q_NULLPTR));
        switchKey->clear();
        switchKey->insertItems(0, QStringList()
         << QApplication::translate("KeyboardLayoutConfig", "None", Q_NULLPTR)
        );
        label_4->setText(QApplication::translate("KeyboardLayoutConfig", "<html><head/><body><p><span style=\" font-weight:600;\">Note</span>: If you are using an <span style=\" font-weight:600;\">input method</span>, such as IBus, uim, fcitx, or gcin, the settings here <span style=\" font-weight:600;\">might not work</span> because they are overridden by the input methods.</p></body></html>", Q_NULLPTR));
        Q_UNUSED(KeyboardLayoutConfig);
    } // retranslateUi

};

namespace Ui {
    class KeyboardLayoutConfig: public Ui_KeyboardLayoutConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_KEYBOARDLAYOUTCONFIG_H
