/********************************************************************************
** Form generated from reading UI file 'mimetypeviewer.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MIMETYPEVIEWER_H
#define UI_MIMETYPEVIEWER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_mimetypeviewer
{
public:
    QGridLayout *gridLayout;
    QFrame *mimeFrame;
    QGroupBox *applicationsGroupBox;
    QPushButton *chooseApplicationsButton;
    QFrame *applicationLabelFrame;
    QHBoxLayout *horizontalLayout;
    QLabel *appIcon;
    QLabel *applicationLabel;
    QGroupBox *patternsGroupBox;
    QLabel *patternsLabel;
    QGroupBox *mimetypeGroupBox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *iconLabel;
    QLabel *descriptionLabel;
    QLineEdit *searchTermLineEdit;
    QDialogButtonBox *dialogButtonBox;
    QTreeWidget *mimetypeTreeWidget;

    void setupUi(QWidget *mimetypeviewer)
    {
        if (mimetypeviewer->objectName().isEmpty())
            mimetypeviewer->setObjectName(QStringLiteral("mimetypeviewer"));
        mimetypeviewer->resize(565, 370);
        mimetypeviewer->setMinimumSize(QSize(530, 370));
        gridLayout = new QGridLayout(mimetypeviewer);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        mimeFrame = new QFrame(mimetypeviewer);
        mimeFrame->setObjectName(QStringLiteral("mimeFrame"));
        mimeFrame->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mimeFrame->sizePolicy().hasHeightForWidth());
        mimeFrame->setSizePolicy(sizePolicy);
        mimeFrame->setMinimumSize(QSize(280, 260));
        mimeFrame->setFrameShape(QFrame::NoFrame);
        mimeFrame->setFrameShadow(QFrame::Plain);
        applicationsGroupBox = new QGroupBox(mimeFrame);
        applicationsGroupBox->setObjectName(QStringLiteral("applicationsGroupBox"));
        applicationsGroupBox->setGeometry(QRect(10, 170, 260, 140));
        chooseApplicationsButton = new QPushButton(applicationsGroupBox);
        chooseApplicationsButton->setObjectName(QStringLiteral("chooseApplicationsButton"));
        chooseApplicationsButton->setGeometry(QRect(140, 90, 110, 30));
        applicationLabelFrame = new QFrame(applicationsGroupBox);
        applicationLabelFrame->setObjectName(QStringLiteral("applicationLabelFrame"));
        applicationLabelFrame->setGeometry(QRect(10, 20, 241, 51));
        applicationLabelFrame->setFrameShape(QFrame::NoFrame);
        applicationLabelFrame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(applicationLabelFrame);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        appIcon = new QLabel(applicationLabelFrame);
        appIcon->setObjectName(QStringLiteral("appIcon"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(appIcon->sizePolicy().hasHeightForWidth());
        appIcon->setSizePolicy(sizePolicy1);
        appIcon->setMinimumSize(QSize(50, 50));

        horizontalLayout->addWidget(appIcon);

        applicationLabel = new QLabel(applicationLabelFrame);
        applicationLabel->setObjectName(QStringLiteral("applicationLabel"));
        applicationLabel->setIndent(10);

        horizontalLayout->addWidget(applicationLabel);

        patternsGroupBox = new QGroupBox(mimeFrame);
        patternsGroupBox->setObjectName(QStringLiteral("patternsGroupBox"));
        patternsGroupBox->setGeometry(QRect(10, 100, 260, 60));
        patternsLabel = new QLabel(patternsGroupBox);
        patternsLabel->setObjectName(QStringLiteral("patternsLabel"));
        patternsLabel->setGeometry(QRect(10, 20, 230, 30));
        patternsLabel->setWordWrap(true);
        mimetypeGroupBox = new QGroupBox(mimeFrame);
        mimetypeGroupBox->setObjectName(QStringLiteral("mimetypeGroupBox"));
        mimetypeGroupBox->setGeometry(QRect(10, 0, 260, 90));
        horizontalLayout_2 = new QHBoxLayout(mimetypeGroupBox);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        iconLabel = new QLabel(mimetypeGroupBox);
        iconLabel->setObjectName(QStringLiteral("iconLabel"));
        sizePolicy1.setHeightForWidth(iconLabel->sizePolicy().hasHeightForWidth());
        iconLabel->setSizePolicy(sizePolicy1);
        iconLabel->setMinimumSize(QSize(50, 50));

        horizontalLayout_2->addWidget(iconLabel);

        descriptionLabel = new QLabel(mimetypeGroupBox);
        descriptionLabel->setObjectName(QStringLiteral("descriptionLabel"));
        descriptionLabel->setWordWrap(true);

        horizontalLayout_2->addWidget(descriptionLabel);


        gridLayout->addWidget(mimeFrame, 2, 1, 2, 1);

        searchTermLineEdit = new QLineEdit(mimetypeviewer);
        searchTermLineEdit->setObjectName(QStringLiteral("searchTermLineEdit"));
        searchTermLineEdit->setMinimumSize(QSize(0, 30));

        gridLayout->addWidget(searchTermLineEdit, 2, 0, 1, 1);

        dialogButtonBox = new QDialogButtonBox(mimetypeviewer);
        dialogButtonBox->setObjectName(QStringLiteral("dialogButtonBox"));
        dialogButtonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        gridLayout->addWidget(dialogButtonBox, 4, 0, 1, 2);

        mimetypeTreeWidget = new QTreeWidget(mimetypeviewer);
        mimetypeTreeWidget->setObjectName(QStringLiteral("mimetypeTreeWidget"));
        QSizePolicy sizePolicy2(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mimetypeTreeWidget->sizePolicy().hasHeightForWidth());
        mimetypeTreeWidget->setSizePolicy(sizePolicy2);
        mimetypeTreeWidget->setMinimumSize(QSize(180, 275));
        mimetypeTreeWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        mimetypeTreeWidget->setProperty("showDropIndicator", QVariant(false));
        mimetypeTreeWidget->setHeaderHidden(true);
        mimetypeTreeWidget->setExpandsOnDoubleClick(false);
        mimetypeTreeWidget->setColumnCount(0);
        mimetypeTreeWidget->header()->setVisible(false);
        mimetypeTreeWidget->header()->setDefaultSectionSize(500);

        gridLayout->addWidget(mimetypeTreeWidget, 3, 0, 1, 1);

        QWidget::setTabOrder(searchTermLineEdit, mimetypeTreeWidget);
        QWidget::setTabOrder(mimetypeTreeWidget, chooseApplicationsButton);

        retranslateUi(mimetypeviewer);

        QMetaObject::connectSlotsByName(mimetypeviewer);
    } // setupUi

    void retranslateUi(QWidget *mimetypeviewer)
    {
        mimetypeviewer->setWindowTitle(QApplication::translate("mimetypeviewer", "File Associations", Q_NULLPTR));
        applicationsGroupBox->setTitle(QApplication::translate("mimetypeviewer", "Default application", Q_NULLPTR));
        chooseApplicationsButton->setText(QApplication::translate("mimetypeviewer", "&Choose...", Q_NULLPTR));
        appIcon->setText(QApplication::translate("mimetypeviewer", "TextLabel", Q_NULLPTR));
        applicationLabel->setText(QApplication::translate("mimetypeviewer", "None", Q_NULLPTR));
        patternsGroupBox->setTitle(QApplication::translate("mimetypeviewer", "Patterns", Q_NULLPTR));
        patternsLabel->setText(QApplication::translate("mimetypeviewer", "*.txt *.xml", Q_NULLPTR));
        mimetypeGroupBox->setTitle(QApplication::translate("mimetypeviewer", "MIME type", Q_NULLPTR));
        iconLabel->setText(QApplication::translate("mimetypeviewer", "Icon", Q_NULLPTR));
        descriptionLabel->setText(QApplication::translate("mimetypeviewer", "Description", Q_NULLPTR));
        searchTermLineEdit->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class mimetypeviewer: public Ui_mimetypeviewer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MIMETYPEVIEWER_H
